==> lasem-0.4.2.tar.xz: lasem-0.4.2/src/lsmmathmlenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef LSM_MATHML_ENUM_TYPES_H
#define LSM_MATHML_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "lsmmathmlenums.h" */

#define LSM_TYPE_MATHML_CSS_TYPE	(lsm_mathml_css_type_get_type())
GType lsm_mathml_css_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_MODE	(lsm_mathml_mode_get_type())
GType lsm_mathml_mode_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_DISPLAY	(lsm_mathml_display_get_type())
GType lsm_mathml_display_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_SPACE_NAME	(lsm_mathml_space_name_get_type())
GType lsm_mathml_space_name_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_UNIT	(lsm_mathml_unit_get_type())
GType lsm_mathml_unit_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_FONT_STYLE	(lsm_mathml_font_style_get_type())
GType lsm_mathml_font_style_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_FONT_WEIGHT	(lsm_mathml_font_weight_get_type())
GType lsm_mathml_font_weight_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_VARIANT	(lsm_mathml_variant_get_type())
GType lsm_mathml_variant_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_FORM	(lsm_mathml_form_get_type())
GType lsm_mathml_form_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_ROW_ALIGN	(lsm_mathml_row_align_get_type())
GType lsm_mathml_row_align_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_COLUMN_ALIGN	(lsm_mathml_column_align_get_type())
GType lsm_mathml_column_align_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_LINE	(lsm_mathml_line_get_type())
GType lsm_mathml_line_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_SCRIPT_LEVEL_SIGN	(lsm_mathml_script_level_sign_get_type())
GType lsm_mathml_script_level_sign_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmltablerowelement.h" */

#define LSM_TYPE_MATHML_TABLE_ROW_ELEMENT_TYPE	(lsm_mathml_table_row_element_type_get_type())
GType lsm_mathml_table_row_element_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlradicalelement.h" */

#define LSM_TYPE_MATHML_RADICAL_ELEMENT_TYPE	(lsm_mathml_radical_element_type_get_type())
GType lsm_mathml_radical_element_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlscriptelement.h" */

#define LSM_TYPE_MATHML_SCRIPT_ELEMENT_TYPE	(lsm_mathml_script_element_type_get_type())
GType lsm_mathml_script_element_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlunderoverelement.h" */

#define LSM_TYPE_MATHML_UNDER_OVER_ELEMENT_TYPE	(lsm_mathml_under_over_element_type_get_type())
GType lsm_mathml_under_over_element_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlpresentationtoken.h" */

#define LSM_TYPE_MATHML_PRESENTATION_TOKEN_TYPE	(lsm_mathml_presentation_token_type_get_type())
GType lsm_mathml_presentation_token_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlview.h" */

#define LSM_TYPE_MATHML_GLYPH_FLAGS	(lsm_mathml_glyph_flags_get_type())
GType lsm_mathml_glyph_flags_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_FONT	(lsm_mathml_font_get_type())
GType lsm_mathml_font_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* LSM_MATHML_ENUM_TYPES_H */

/* Generated data ends here */

==> lasem-0.5.0.tar.xz: lasem-0.5.0/src/lsmmathmlenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef LSM_MATHML_ENUM_TYPES_H
#define LSM_MATHML_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "lsmmathmlenums.h" */

#define LSM_TYPE_MATHML_CSS_TYPE	(lsm_mathml_css_type_get_type())
GType lsm_mathml_css_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_MODE	(lsm_mathml_mode_get_type())
GType lsm_mathml_mode_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_DISPLAY	(lsm_mathml_display_get_type())
GType lsm_mathml_display_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_SPACE_NAME	(lsm_mathml_space_name_get_type())
GType lsm_mathml_space_name_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_UNIT	(lsm_mathml_unit_get_type())
GType lsm_mathml_unit_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_FONT_STYLE	(lsm_mathml_font_style_get_type())
GType lsm_mathml_font_style_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_FONT_WEIGHT	(lsm_mathml_font_weight_get_type())
GType lsm_mathml_font_weight_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_VARIANT	(lsm_mathml_variant_get_type())
GType lsm_mathml_variant_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_FORM	(lsm_mathml_form_get_type())
GType lsm_mathml_form_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_ROW_ALIGN	(lsm_mathml_row_align_get_type())
GType lsm_mathml_row_align_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_COLUMN_ALIGN	(lsm_mathml_column_align_get_type())
GType lsm_mathml_column_align_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_LINE	(lsm_mathml_line_get_type())
GType lsm_mathml_line_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_SCRIPT_LEVEL_SIGN	(lsm_mathml_script_level_sign_get_type())
GType lsm_mathml_script_level_sign_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_NOTATION	(lsm_mathml_notation_get_type())
GType lsm_mathml_notation_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmltablerowelement.h" */

#define LSM_TYPE_MATHML_TABLE_ROW_ELEMENT_TYPE	(lsm_mathml_table_row_element_type_get_type())
GType lsm_mathml_table_row_element_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlradicalelement.h" */

#define LSM_TYPE_MATHML_RADICAL_ELEMENT_TYPE	(lsm_mathml_radical_element_type_get_type())
GType lsm_mathml_radical_element_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlscriptelement.h" */

#define LSM_TYPE_MATHML_SCRIPT_ELEMENT_TYPE	(lsm_mathml_script_element_type_get_type())
GType lsm_mathml_script_element_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlunderoverelement.h" */

#define LSM_TYPE_MATHML_UNDER_OVER_ELEMENT_TYPE	(lsm_mathml_under_over_element_type_get_type())
GType lsm_mathml_under_over_element_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlpresentationtoken.h" */

#define LSM_TYPE_MATHML_PRESENTATION_TOKEN_TYPE	(lsm_mathml_presentation_token_type_get_type())
GType lsm_mathml_presentation_token_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmmathmlview.h" */

#define LSM_TYPE_MATHML_GLYPH_FLAGS	(lsm_mathml_glyph_flags_get_type())
GType lsm_mathml_glyph_flags_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_MATHML_FONT	(lsm_mathml_font_get_type())
GType lsm_mathml_font_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* LSM_MATHML_ENUM_TYPES_H */

/* Generated data ends here */
